pub struct DIVec2 {
pub x: i64,
pub y: i64,
}Expand description
an double interger vector made from a x and y coordinate.
Fields
x: i64y: i64Implementations
sourceimpl DIVec2
impl DIVec2
pub fn new(x: i64, y: i64) -> Self
pub fn extend(self, z: i64) -> DIVec3
pub fn truncate(self) -> i64
sourcepub fn length_squared(self) -> i64
pub fn length_squared(self) -> i64
the length of the vector without being square rooted.
sourcepub fn distance_squared(self, other: DIVec2) -> i64
pub fn distance_squared(self, other: DIVec2) -> i64
distance between two vectors without being square rooted.