pub struct DIVec3 {
pub x: i64,
pub y: i64,
pub z: i64,
}Expand description
an double interger vector made from a x, y and z coordinate.
Fields
x: i64y: i64z: i64Implementations
sourceimpl DIVec3
impl DIVec3
pub fn new(x: i64, y: i64, z: i64) -> Self
pub fn extend(self, w: i64) -> DIVec4
pub fn truncate(self) -> DIVec2
sourcepub fn length_squared(self) -> i64
pub fn length_squared(self) -> i64
the length of the vector before being square rooted.
sourcepub fn distance_squared(self, other: DIVec3) -> i64
pub fn distance_squared(self, other: DIVec3) -> i64
distance between two vectors before being square rooted.
sourcepub fn dot(self, other: DIVec3) -> i64
pub fn dot(self, other: DIVec3) -> i64
get the dot product of 2 vectors. equal to the cosign of the angle between vectors.
sourcepub fn cross(&self, other: DIVec3) -> DIVec3
pub fn cross(&self, other: DIVec3) -> DIVec3
get the cross product of 2 vectors. equal to the vector that is perpendicular to both input vectors. the output vector is not normalised.
use glium_types::vectors::{DIVec3, divec3};
let x = divec3(1, 0, 0);
let y = divec3(0, 1, 0);
let z = divec3(0, 0, 1);
assert!(x.cross(y) == z);Trait Implementations
sourceimpl AddAssign for DIVec3
impl AddAssign for DIVec3
sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moresourceimpl AsUniformValue for DIVec3
impl AsUniformValue for DIVec3
sourcefn as_uniform_value(&self) -> UniformValue<'_>
fn as_uniform_value(&self) -> UniformValue<'_>
Builds a
UniformValue.sourceimpl DivAssign for DIVec3
impl DivAssign for DIVec3
sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
Performs the
/= operation. Read moresourceimpl MulAssign for DIVec3
impl MulAssign for DIVec3
sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Performs the
*= operation. Read moresourceimpl Ord for DIVec3
impl Ord for DIVec3
sourceimpl PartialOrd for DIVec3
impl PartialOrd for DIVec3
sourceimpl RemAssign for DIVec3
impl RemAssign for DIVec3
sourcefn rem_assign(&mut self, rhs: Self)
fn rem_assign(&mut self, rhs: Self)
Performs the
%= operation. Read moresourceimpl SubAssign for DIVec3
impl SubAssign for DIVec3
sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read moreimpl Copy for DIVec3
impl Eq for DIVec3
impl StructuralPartialEq for DIVec3