Struct glium_types::vectors::UVec2
source · pub struct UVec2 {
pub x: u32,
pub y: u32,
}Expand description
an unsigned interger vector made from a x and y coordinate.
Fields
x: u32y: u32Implementations
sourceimpl UVec2
impl UVec2
pub fn new(x: u32, y: u32) -> Self
pub fn extend(self, z: u32) -> UVec3
pub fn truncate(self) -> u32
sourcepub fn length_squared(self) -> u32
pub fn length_squared(self) -> u32
the length of the vector without being square rooted.
sourcepub fn distance_squared(self, other: UVec2) -> u32
pub fn distance_squared(self, other: UVec2) -> u32
distance between two vectors without being square rooted.