Struct glium_types::vectors::UVec3
source · pub struct UVec3 {
pub x: u32,
pub y: u32,
pub z: u32,
}Expand description
an unsigned interger vector made from a x, y and z coordinate.
Fields
x: u32y: u32z: u32Implementations
sourceimpl UVec3
impl UVec3
pub fn new(x: u32, y: u32, z: u32) -> Self
pub fn extend(self, w: u32) -> UVec4
pub fn truncate(self) -> UVec2
sourcepub fn length_squared(self) -> u32
pub fn length_squared(self) -> u32
the length of the vector before being square rooted.
sourcepub fn distance_squared(self, other: UVec3) -> u32
pub fn distance_squared(self, other: UVec3) -> u32
distance between two vectors before being square rooted.
sourcepub fn dot(self, other: UVec3) -> u32
pub fn dot(self, other: UVec3) -> u32
get the dot product of 2 vectors. equal to the cosign of the angle between vectors.
sourcepub fn cross(&self, other: UVec3) -> UVec3
pub fn cross(&self, other: UVec3) -> UVec3
get the cross product of 2 vectors. equal to the vector that is perpendicular to both input vectors. the output vector is not normalised.
use glium_types::vectors::{UVec3, uvec3};
let x = uvec3(1, 0, 0);
let y = uvec3(0, 1, 0);
let z = uvec3(0, 0, 1);
assert!(x.cross(y) == z);Trait Implementations
sourceimpl AddAssign for UVec3
impl AddAssign for UVec3
sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moresourceimpl AsUniformValue for UVec3
impl AsUniformValue for UVec3
sourcefn as_uniform_value(&self) -> UniformValue<'_>
fn as_uniform_value(&self) -> UniformValue<'_>
Builds a
UniformValue.sourceimpl DivAssign for UVec3
impl DivAssign for UVec3
sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
Performs the
/= operation. Read moresourceimpl MulAssign for UVec3
impl MulAssign for UVec3
sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Performs the
*= operation. Read moresourceimpl Ord for UVec3
impl Ord for UVec3
sourceimpl PartialEq for UVec3
impl PartialEq for UVec3
sourceimpl PartialOrd for UVec3
impl PartialOrd for UVec3
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl RemAssign for UVec3
impl RemAssign for UVec3
sourcefn rem_assign(&mut self, rhs: Self)
fn rem_assign(&mut self, rhs: Self)
Performs the
%= operation. Read moresourceimpl SubAssign for UVec3
impl SubAssign for UVec3
sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read moreimpl Copy for UVec3
impl Eq for UVec3
impl StructuralPartialEq for UVec3