Struct glium_types::vectors::Vec2
source · pub struct Vec2 {
pub x: f32,
pub y: f32,
}Expand description
a vector made from a x and y coordinate.
Fields
x: f32y: f32Implementations
sourceimpl Vec2
impl Vec2
pub fn new(x: f32, y: f32) -> Self
pub fn extend(self, z: f32) -> Vec3
pub fn truncate(self) -> f32
sourcepub fn length_squared(self) -> f32
pub fn length_squared(self) -> f32
the length of the vector before being square rooted.
sourcepub fn distance_squared(self, other: Vec2) -> f32
pub fn distance_squared(self, other: Vec2) -> f32
distance between two vectors before being square rooted.
sourcepub fn dot(self, other: Vec2) -> f32
pub fn dot(self, other: Vec2) -> f32
get the dot product of 2 vectors. equal to the cosign of the angle between vectors.