Struct glium_types::vectors::Vec3
source · pub struct Vec3 {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
a vector made from a x, y and z coordinate.
Fields
x: f32y: f32z: f32Implementations
sourceimpl Vec3
impl Vec3
pub fn new(x: f32, y: f32, z: f32) -> Self
pub fn extend(self, w: f32) -> Vec4
pub fn truncate(self) -> Vec2
sourcepub fn length_squared(self) -> f32
pub fn length_squared(self) -> f32
the length of the vector before being square rooted.
sourcepub fn distance_squared(self, other: Vec3) -> f32
pub fn distance_squared(self, other: Vec3) -> f32
distance between two vectors before being square rooted.
sourcepub fn dot(self, other: Vec3) -> f32
pub fn dot(self, other: Vec3) -> f32
get the dot product of 2 vectors. equal to the cosign of the angle between vectors.
sourcepub fn cross(&self, other: Vec3) -> Vec3
pub fn cross(&self, other: Vec3) -> Vec3
get the cross product of 2 vectors. equal to the vector that is perpendicular to both input vectors. the output vector is not normalised.
use glium_types::vectors::{Vec3, vec3};
let x = vec3(1.0, 0.0, 0.0);
let y = vec3(0.0, 1.0, 0.0);
let z = vec3(0.0, 0.0, 1.0);
assert!(x.cross(y) == z);Trait Implementations
sourceimpl AddAssign for Vec3
impl AddAssign for Vec3
sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moresourceimpl AsUniformValue for Vec3
impl AsUniformValue for Vec3
sourcefn as_uniform_value(&self) -> UniformValue<'_>
fn as_uniform_value(&self) -> UniformValue<'_>
Builds a
UniformValue.sourceimpl DivAssign for Vec3
impl DivAssign for Vec3
sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
Performs the
/= operation. Read moresourceimpl MulAssign for Vec3
impl MulAssign for Vec3
sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Performs the
*= operation. Read moresourceimpl PartialEq for Vec3
impl PartialEq for Vec3
sourceimpl PartialOrd for Vec3
impl PartialOrd for Vec3
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl RemAssign for Vec3
impl RemAssign for Vec3
sourcefn rem_assign(&mut self, rhs: Self)
fn rem_assign(&mut self, rhs: Self)
Performs the
%= operation. Read moresourceimpl SubAssign for Vec3
impl SubAssign for Vec3
sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read moreimpl Copy for Vec3
impl StructuralPartialEq for Vec3